# python-xymon-client

A minimalist [Xymon](https://www.xymon.com/) client library and CLI in Python.

Documentation is in the docs directory or [online](http://python-xymon-client.readthedocs.io/en/latest/).

Features:

* Python 3.10;
  but should work with Python ≥ 3.6 if you remove the annotations
  (a tool such as [python-minifier](https://github.com/dflook/python-minifier) can do it for you)
* no dependencies
* command line interface
* easy to use and extend

## Examples

As CLI:
```bash
$ xymon-client -s xymon01.example.net query --hostname www-portal.example.net --testname info
'yellow Message generated by c234d183-069b-447e-73ab-84d5 at 2019-01-29T16:14:01\n'
```

As a Python library:
```python
from xymon_client import Xymon
xymon = Xymon('xymonserver01.example.net')
xymon.ping()
'xymond 4.3.18\n'
```

## Alternatives

* https://github.com/skurfer/python-xymon
